/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.common.source;

public class TypeDefineUtils {
    public static Long charToDoubleByteLength(Long charLength) {
        if (charLength == null) {
            return null;
        }
        return charLength * 2;
    }

    public static Long doubleByteTo4ByteLength(Long doubleByteLength) {
        if (doubleByteLength == null) {
            return null;
        }
        return doubleByteLength * 2;
    }

    public static Long charTo4ByteLength(Long charLength) {
        return charToByteLength(charLength, 4);
    }

    public static Long charToByteLength(Long charLength, int byteSize) {
        if (charLength == null) {
            return null;
        }
        return charLength * byteSize;
    }
}
